@@ -1,4 +1,5 @@
 # pylint: disable = too-many-instance-attributes, W0212
+import asyncio
 import copy
 import functools
 import traceback
@@ -20,6 +21,7 @@ from .typing import (
     T_GroupMsgMiddleware,
     T_GroupMsgReceiver,
 )
+from .utils import sync_run
 
 #######################
 #     socketio
@@ -35,7 +37,7 @@ from .typing import (
 class Botoy:
     """
     :param qq: 机器人QQ号(多Q就传qq号列表), 如果不传则会监听服务端传过来的所有机器人的
-                所有信息，如果传了，则只会接收对应机器人的信息
+                所有信息，如果传了，则只会接收对应机器人的信息. 0会被忽略，相当于没传
     :param use_plugins: 是否开启插件功能, 默认``False``
     :param port: 运行端口, 默认为``8888``
     :param host: ip，默认为``http://127.0.0.1``
@@ -66,7 +68,7 @@ class Botoy:
                 self.qq = [qq]  # type: ignore
         else:
             self.qq = []
-        self.qq: List[int] = [int(qq) for qq in self.qq]
+        self.qq: List[int] = [int(qq) for qq in self.qq if int(qq) != 0]
 
         self.config = Config(
             host, port, group_blacklist, friend_blacklist, blocked_users
@@ -92,9 +94,11 @@ class Botoy:
         if self.config.webhook:
             from . import webhook  # pylint: disable=C0415
 
-            self._friend_msg_receivers.append(webhook.receive_friend_msg)
-            self._group_msg_receivers.append(webhook.receive_group_msg)
-            self._event_receivers.append(webhook.receive_events)
+            flag = self.__class__.__name__.startswith("Async") and "async_" or ""
+
+            self._friend_msg_receivers.append(getattr(webhook, f"{flag}friend"))
+            self._group_msg_receivers.append(getattr(webhook, f"{flag}group"))
+            self._event_receivers.append(getattr(webhook, f"{flag}event"))
 
         # 插件管理
         # 管理插件提供的接收函数
@@ -175,7 +179,11 @@ class Botoy:
     ########################################################################
     def _context_distributor(self, context: Union[FriendMsg, GroupMsg, EventMsg]):
         for receiver in self._get_context_receivers(context):
-            self.pool.submit(receiver, copy.deepcopy(context))
+            new_context = copy.deepcopy(context)
+            if asyncio.iscoroutinefunction(receiver):
+                self.pool.submit(sync_run, receiver(new_context))  # type: ignore
+            else:
+                self.pool.submit(receiver, new_context)
 
     def _get_context_receivers(self, context: Union[FriendMsg, GroupMsg, EventMsg]):
 
